# npm-api-dependents [![NPM version](https://img.shields.io/npm/v/npm-api-dependents.svg)](https://www.npmjs.com/package/npm-api-dependents) [![Build Status](https://img.shields.io/travis/doowb/npm-api-dependents.svg)](https://travis-ci.org/doowb/npm-api-dependents)

> npm-api plugin for getting module dependents.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install npm-api-dependents --save
```

## Usage

```js
var npm = require('npm-api')();
var dependents = require('npm-api-dependents');
npm.use(dependents());

var repo = npm.repo('micromatch');

// returns a Promise
repo.dependents()
  .then(function(repos) {
    console.log(repos);
  }, function(err) {
    console.error(err);
  });

// use with co
co(function* () {
  var repos = yield repo.dependents();
  console.log(repos);
});
```

## API

### [.dependents](index.js#L46)

Get the dependents for the current repo.

**Params**

* `options` **{Object}**: Options to handle returned results
* `options.mapFn` **{Function}**: Optional map function to handle transforming the repo name into something else. Takes `(name, index, repos, options)` and called in the context of the [npm-api](https://github.com/doowb/npm-api) instance.
* `returns` **{Promise}**: Returns an array of module names when promise resolves.

**Example**

```js
var repo = npm.repo('micromatch');

// returns a promise
repo.dependents()
  .then(function(repos) {
    console.log(repos);
  }, function(err) {
    console.error(err);
  });

// use with co and generator functions
co(function* () {
  var repos = yield repo.dependents();
  console.log(repos);
});
```

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/doowb/npm-api-dependents/issues/new).

## Building docs

Generate readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install verb && npm run docs
```

Or, if [verb](https://github.com/verbose/verb) is installed globally:

```sh
$ verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Brian Woodward**

* [github/doowb](https://github.com/doowb)
* [twitter/doowb](http://twitter.com/doowb)

## License

Copyright © 2016 [Brian Woodward](https://github.com/doowb)
Released under the [MIT license](https://github.com/doowb/npm-api-dependents/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on March 23, 2016._